@@ -42,37 +42,37 @@ impl App {
             .modifiers
             .contains(crossterm::event::KeyModifiers::CONTROL)
         {
-            result.push_str("Ctrl+");
+            result.push_str(&t!("keys.mods.control"));
         }
         if event
             .modifiers
             .contains(crossterm::event::KeyModifiers::ALT)
         {
-            result.push_str("Alt+");
+            result.push_str(&t!("keys.mods.alt"));
         }
         if event
             .modifiers
             .contains(crossterm::event::KeyModifiers::SHIFT)
         {
-            result.push_str("Shift+");
+            result.push_str(&t!("keys.mods.shift"));
         }
         if event
             .modifiers
             .contains(crossterm::event::KeyModifiers::SUPER)
         {
-            result.push_str("Super+");
+            result.push_str(&t!("keys.mods.super"));
         }
         if event
             .modifiers
             .contains(crossterm::event::KeyModifiers::HYPER)
         {
-            result.push_str("Hyper+");
+            result.push_str(&t!("keys.mods.hyper"));
         }
         if event
             .modifiers
             .contains(crossterm::event::KeyModifiers::META)
         {
-            result.push_str("Meta+");
+            result.push_str(&t!("keys.mods.meta"));
         }
 
         result.push_str(&match event.code {
@@ -84,12 +84,28 @@ impl App {
                 format!("F{}", n)
             }
             crossterm::event::KeyCode::Char(c) => match c {
-                ' ' => "Space".into(),
-                '\t' => "Tab".into(),
+                ' ' => t!("keys.space").into(),
+                '\t' => t!("keys.tab").into(),
                 '\n' => "LF".into(),
                 '\r' => "CR".into(),
                 _ => c.to_ascii_uppercase().to_string(),
             },
+            crossterm::event::KeyCode::Enter => t!("keys.enter").into(),
+            crossterm::event::KeyCode::Esc => t!("keys.esc").into(),
+            crossterm::event::KeyCode::Backspace => t!("keys.backspace").into(),
+            crossterm::event::KeyCode::Delete => t!("keys.delete").into(),
+            crossterm::event::KeyCode::Home => t!("keys.home").into(),
+            crossterm::event::KeyCode::End => t!("keys.end").into(),
+            crossterm::event::KeyCode::PageUp => t!("keys.page_up").into(),
+            crossterm::event::KeyCode::PageDown => t!("keys.page_down").into(),
+            crossterm::event::KeyCode::Insert => t!("keys.insert").into(),
+            crossterm::event::KeyCode::Tab => t!("keys.tab").into(),
+            crossterm::event::KeyCode::Null => t!("keys.null").into(),
+            crossterm::event::KeyCode::CapsLock => t!("keys.caps_lock").into(),
+            crossterm::event::KeyCode::ScrollLock => t!("keys.scroll_lock").into(),
+            crossterm::event::KeyCode::NumLock => t!("keys.num_lock").into(),
+            crossterm::event::KeyCode::PrintScreen => t!("keys.print_screen").into(),
+            crossterm::event::KeyCode::Pause => t!("keys.pause").into(),
             c => format!("{:?}", c),
         });
         result
@@ -97,98 +113,134 @@ impl App {
 
     pub(super) fn help_list(key_settings: &KeySettings) -> Vec<HelpLine> {
         vec![
-            HelpLine::new(&Self::key_event_to_string(key_settings.up), "Move up"),
-            HelpLine::new(&Self::key_event_to_string(key_settings.down), "Move down"),
-            HelpLine::new(&Self::key_event_to_string(key_settings.left), "Move left"),
-            HelpLine::new(&Self::key_event_to_string(key_settings.right), "Move right"),
+            HelpLine::new(
+                &Self::key_event_to_string(key_settings.up),
+                &t!("app.help.up"),
+            ),
+            HelpLine::new(
+                &Self::key_event_to_string(key_settings.down),
+                &t!("app.help.down"),
+            ),
+            HelpLine::new(
+                &Self::key_event_to_string(key_settings.left),
+                &t!("app.help.left"),
+            ),
+            HelpLine::new(
+                &Self::key_event_to_string(key_settings.right),
+                &t!("app.help.right"),
+            ),
             HelpLine::new(
                 &Self::key_event_to_string(key_settings.next),
-                "Next instruction or block",
+                &t!("app.help.next"),
             ),
             HelpLine::new(
                 &Self::key_event_to_string(key_settings.previous),
-                "Previous instruction or block",
+                &t!("app.help.previous"),
             ),
             HelpLine::new(
                 &Self::key_event_to_string(key_settings.page_up),
-                "Scroll up",
+                &t!("app.help.page_up"),
             ),
             HelpLine::new(
                 &Self::key_event_to_string(key_settings.page_down),
-                "Scroll down",
+                &t!("app.help.page_down"),
             ),
             HelpLine::new(
                 &Self::key_event_to_string(key_settings.goto_start),
-                "Scroll to start",
+                &t!("app.help.goto_start"),
             ),
             HelpLine::new(
                 &Self::key_event_to_string(key_settings.goto_end),
-                "Scroll to end",
+                &t!("app.help.goto_end"),
+            ),
+            HelpLine::new(
+                &Self::key_event_to_string(key_settings.run),
+                &t!("app.help.run"),
+            ),
+            HelpLine::new(
+                &Self::key_event_to_string(key_settings.save),
+                &t!("app.help.save"),
+            ),
+            HelpLine::new(
+                &Self::key_event_to_string(key_settings.save_as),
+                &t!("app.help.save_as"),
             ),
-            HelpLine::new(&Self::key_event_to_string(key_settings.run), "Run command"),
-            HelpLine::new(&Self::key_event_to_string(key_settings.save), "Save"),
-            HelpLine::new(&Self::key_event_to_string(key_settings.save_as), "Save as"),
             HelpLine::new(
                 &Self::key_event_to_string(key_settings.save_and_quit),
-                "Save and quit",
+                &t!("app.help.save_and_quit"),
+            ),
+            HelpLine::new(
+                &Self::key_event_to_string(key_settings.quit),
+                &t!("app.help.quit"),
+            ),
+            HelpLine::new(
+                &Self::key_event_to_string(key_settings.open),
+                &t!("app.help.open"),
             ),
-            HelpLine::new(&Self::key_event_to_string(key_settings.quit), "Quit"),
-            HelpLine::new(&Self::key_event_to_string(key_settings.open), "Open file"),
             HelpLine::new(
                 &Self::key_event_to_string(key_settings.change_view),
-                "Switch view from assembly to text or viceversa",
+                &t!("app.help.change_view"),
             ),
             HelpLine::new(
                 &Self::key_event_to_string(key_settings.change_selected_pane),
-                "Switch from the hex pane to assembly/text or viceversa",
+                &t!("app.help.change_selected_pane"),
             ),
             HelpLine::new(
                 &Self::key_event_to_string(key_settings.fullscreen),
-                "Toggle the fullscreen for the selected view",
+                &t!("app.help.fullscreen"),
             ),
             HelpLine::new(
                 &Self::key_event_to_string(key_settings.jump),
-                "Jump to location",
+                &t!("app.help.jump"),
             ),
             HelpLine::new(
                 &Self::key_event_to_string(key_settings.find_symbol),
-                "Search symbol",
+                &t!("app.help.find_symbol"),
             ),
             HelpLine::new(
                 &Self::key_event_to_string(key_settings.find_text),
-                "Search text",
+                &t!("app.help.find_text"),
             ),
             HelpLine::new(
                 &Self::key_event_to_string(key_settings.patch_text),
-                "Patch text",
+                &t!("app.help.patch_text"),
             ),
             HelpLine::new(
                 &Self::key_event_to_string(key_settings.patch_assembly),
-                "Patch assembly",
+                &t!("app.help.patch_assembly"),
+            ),
+            HelpLine::new(
+                &Self::key_event_to_string(key_settings.log),
+                &t!("app.help.log"),
+            ),
+            HelpLine::new(
+                &Self::key_event_to_string(key_settings.confirm),
+                &t!("app.help.confirm"),
             ),
-            HelpLine::new(&Self::key_event_to_string(key_settings.log), "Open log"),
-            HelpLine::new(&Self::key_event_to_string(key_settings.confirm), "Confirm"),
             HelpLine::new(
                 &Self::key_event_to_string(key_settings.close_popup),
-                "Close popup",
+                &t!("app.help.close_popup"),
             ),
             HelpLine::new(
                 &Self::key_event_to_string(key_settings.new_line),
-                "Insert new line (with multiline text)",
+                &t!("app.help.new_line"),
             ),
             HelpLine::new(
                 &Self::key_event_to_string(key_settings.clear_log),
-                "Clear log (with log open)",
+                &t!("app.help.clear_log"),
             ),
             HelpLine::new(
                 &Self::key_event_to_string(key_settings.undo),
-                "Undo last change",
+                &t!("app.help.undo"),
             ),
             HelpLine::new(
                 &Self::key_event_to_string(key_settings.redo),
-                "Redo last change",
+                &t!("app.help.redo"),
+            ),
+            HelpLine::new(
+                &Self::key_event_to_string(key_settings.help),
+                &t!("app.help.help"),
             ),
-            HelpLine::new(&Self::key_event_to_string(key_settings.help), "Help"),
         ]
     }
 }
