@@ -11,9 +11,9 @@ pub enum BinaryChoice {
 impl BinaryChoice {
     pub fn to_line(&self, color_settings: &ColorSettings) -> Line<'static> {
         let mut ret = Line::from(vec![
-            Span::styled("Yes", color_settings.yes),
+            Span::styled(t!("app.yes"), color_settings.yes),
             Span::raw("  "),
-            Span::styled("No", color_settings.no),
+            Span::styled(t!("app.no"), color_settings.no),
         ]);
 
         match self {
