@@ -8,32 +8,35 @@ use crossterm::{
 };
 use hex_patch::{app::App, args};
 use ratatui::backend::CrosstermBackend;
+#[macro_use]
+extern crate rust_i18n;
+
+i18n!();
 
 fn main() {
     let args = args::Args::parse();
     let theme = termbg::theme(Duration::from_secs(2));
 
-    enable_raw_mode().expect("Failed to enable raw mode");
+    enable_raw_mode().expect(&t!("errors.enable_raw_mode"));
     let mut stdout = std::io::stdout();
-    execute!(stdout, EnterAlternateScreen, EnableMouseCapture)
-        .expect("Failed to execute setup commands");
+    execute!(stdout, EnterAlternateScreen, EnableMouseCapture).expect(&t!("errors.setup_commands"));
     let backend = CrosstermBackend::new(stdout);
-    let mut terminal = ratatui::Terminal::new(backend).expect("Failed to create terminal");
+    let mut terminal = ratatui::Terminal::new(backend).expect(&t!("errors.create_terminal"));
 
-    terminal.clear().expect("Failed to clear terminal");
-    let mut app = App::new(args, &mut terminal, theme).expect("Failed to create app");
+    terminal.clear().expect(&t!("errors.clear_terminal"));
+    let mut app = App::new(args, &mut terminal, theme).expect(&t!("errors.create_app"));
     let res = app.run(&mut terminal);
-    terminal.clear().expect("Failed to clear terminal");
+    terminal.clear().expect(&t!("errors.clear_terminal"));
 
-    disable_raw_mode().expect("Failed to disable raw mode");
+    disable_raw_mode().expect(&t!("errors.disable_raw_mode"));
 
     execute!(
         terminal.backend_mut(),
         LeaveAlternateScreen,
         DisableMouseCapture
     )
-    .expect("Failed to execute teardown commands");
-    terminal.show_cursor().expect("Failed to show cursor");
+    .expect(&t!("errors.teardown_commands"));
+    terminal.show_cursor().expect(&t!("errors.show_cursor"));
 
     if let Err(err) = res {
         println!("{:?}", err)
